@@ -10,7 +10,7 @@ sprite.rot = rabbyt.lerp(0, 360, dt=6000, extend="repeat")
 sprite.x = 100
 sprite.rgb = 0,1,1
 
-while not pygame.event.peek(pygame.QUIT):
+while not pygame.event.get(pygame.QUIT):
     rabbyt.clear((0,.5,.5,1))
     rabbyt.set_time(pygame.time.get_ticks())
     sprite.render()
